# core deployments

## CNI

Add repo if not present already:
```
helm repo add cilium https://helm.cilium.io/
```
Install chart:
```
helm install cilium cilium/cilium --namespace=kube-system --set ipv4.enabled=true --set ipv6.enabled=true
```

## ingress

Add repo if not present already:
```
helm repo add nginx-stable https://helm.nginx.com/stable
```
Install chart:
```
helm install nginx-ingress nginx-stable/nginx-ingress --namespace nginx --create-namespace -f ingress/values.yaml
```

## certbot
Add CRDs:
```
kubectl apply -f https://github.com/cert-manager/cert-manager/releases/download/v1.11.0/cert-manager.crds.yaml
```
Add repo if not present already:
```
helm repo add jetstack https://charts.jetstack.io
```
Install chart:
```
helm install certbot --namespace cert-manager --create-namespace --version v1.11.0 jetstack/cert-manager
```
Install ClusterIssuer:
```
kubectl apply -f certbot/clusterissuer.yaml
```

## storage

Add repo if not present already:
```
helm repo add rook-release https://charts.rook.io/release
```
Install chart:
```
helm install --create-namespace --namespace rook-ceph rook-ceph rook-release/rook-ceph
```
Install chart:
```
helm install --create-namespace --namespace rook-ceph rook-ceph-cluster rook-release/rook-ceph-cluster -f storage/values.yaml
```
Install Ingress for Dashboard and the StorageClasses:
```
kubectl apply -f storage/dashboard.yaml -f storage/storageclass.yaml
```

## argo cd
Add Namespace:
```
kubectl create namespace argocd
```
Add Argo CD:
```
kubectl apply -n argocd -f https://raw.githubusercontent.com/argoproj/argo-cd/stable/manifests/install.yaml
```


## tests

Install Test Deployments:
```
kubectl apply -f tests/test-ingress.yaml -f tests/test-storage.yaml
```